| spacyr-methods | R Documentation |
These functions provide quanteda methods for spacyr objects, and also extend spacy_parse and spacy_tokenize to work directly with corpus objects.
spacy_parse(x, ...) and spacy_tokenize(x, ...) work directly on
quanteda corpus objects.
In the methods below, x is an object returned by spacy_parse (or, for
spacy_parse, a corpus object), and ... is not used.
docnames(x) returns the document names
ndoc(x) returns the number of documents
ntoken(x, ...) returns the number of tokens by document
ntype(x, ...) returns the number of types (unique tokens) by document
nsentence(x) returns the number of sentences by document
## Not run:
library("spacyr")
spacy_initialize()
corp <- corpus(c(doc1 = "And now, now, now for something completely different.",
doc2 = "Jack and Jill are children."))
spacy_tokenize(corp)
(parsed <- spacy_parse(corp))
ntype(parsed)
ntoken(parsed)
ndoc(parsed)
docnames(parsed)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.